@@ -1,6 +1,6 @@
 require "test_helper"
 
-class ModuleSnapshotTest < Test::Unit::TestCase
+class ModuleSnapshotTest < Minitest::Test
 
   def test_detect_module_method_on_module
     for_all_method_visibilities do |visibility|
@@ -37,4 +37,4 @@ class ModuleSnapshotTest < Test::Unit::TestCase
       assert_method_exists(mod, superdupermod, :foo, visibility)
     end
   end
-end
\ No newline at end of file
+end
